/**
 * This file is part of the NocoBase (R) project.
 * Copyright (c) 2020-2024 NocoBase Co., Ltd.
 * Authors: NocoBase Team.
 *
 * This project is dual-licensed under AGPL-3.0 and NocoBase Commercial License.
 * For more information, please refer to: https://www.nocobase.com/agreement.
 */

import { SchemaComponent, useCurrentRoleVariable, useCurrentUserVariable, useDatetimeVariable } from '@nocobase/client';
import React from 'react';
import { AvatarSelect } from './AvatarSelect';
import { useT } from '../../locale';

const useVariableOptions = () => {
  const t = useT();
  const { currentUserSettings } = useCurrentUserVariable({
    maxDepth: 3,
    noDisabled: true,
  });
  const { currentRoleSettings } = useCurrentRoleVariable({
    noDisabled: true,
  });
  const { datetimeSettings } = useDatetimeVariable({ noDisabled: true });
  return [
    currentUserSettings,
    currentRoleSettings,
    {
      key: '$nLang',
      value: '$nLang',
      label: t('Current language'),
    },
    datetimeSettings,
  ];
};

export const ProfileSettings: React.FC<{
  edit?: boolean;
}> = ({ edit }) => {
  const t = useT();
  const options = useVariableOptions();
  return (
    <SchemaComponent
      scope={{ t }}
      components={{ AvatarSelect }}
      schema={{
        type: 'void',
        properties: {
          username: {
            type: 'string',
            title: '{{t("Username")}}',
            'x-decorator': 'FormItem',
            'x-component': 'Input',
            required: true,
            'x-disabled': edit,
          },
          nickname: {
            type: 'string',
            title: '{{t("Nickname")}}',
            'x-decorator': 'FormItem',
            'x-component': 'Input',
            required: true,
          },
          position: {
            type: 'string',
            title: '{{t("Position")}}',
            'x-decorator': 'FormItem',
            'x-component': 'Input',
            description: t('Position description'),
            'x-component-props': {
              placeholder: t('Position placeholder'),
            },
          },
          avatar: {
            type: 'string',
            title: '{{t("Avatar")}}',
            'x-decorator': 'FormItem',
            'x-component': 'AvatarSelect',
          },
          bio: {
            type: 'string',
            title: '{{t("Bio")}}',
            'x-decorator': 'FormItem',
            'x-component': 'Input.TextArea',
            'x-component-props': {
              placeholder: t('Bio placeholder'),
            },
          },
          about: {
            type: 'string',
            title: '{{t("About me")}}',
            required: true,
            'x-decorator': 'FormItem',
            'x-component': 'Variable.RawTextArea',
            'x-component-props': {
              scope: options,
              placeholder: t('About me placeholder'),
              autoSize: {
                minRows: 15,
              },
            },
          },
          greeting: {
            type: 'string',
            title: '{{t("Greeting message")}}',
            'x-decorator': 'FormItem',
            'x-component': 'Input.TextArea',
            'x-component-props': {
              placeholder: t('Greeting message placeholder'),
            },
          },
        },
      }}
    />
  );
};
